@@ -2,10 +2,10 @@ from piscat.GUI.Visualization import image_viewer
 from piscat.Preproccessing import Normalization
 from skimage.draw import circle_perimeter
 
-from PySide2 import QtGui
-from PySide2 import QtCore
-from PySide2 import QtWidgets
-from PySide2.QtCore import *
+from PySide6 import QtGui
+from PySide6 import QtCore
+from PySide6 import QtWidgets
+from PySide6.QtCore import *
 
 from tqdm import tqdm
 from joblib import Parallel, delayed
@@ -22,10 +22,22 @@ class Visulization_localization(QtWidgets.QMainWindow):
         self.current_frame_number = 0
         self.threadpool = QThreadPool()
         self.filename = filename
+        self.flag_all_localization_df = False
+        self.flag_all_localization_ndarray = False
 
     @QtCore.Slot()
     def get_sliceNumber(self, frame_num):
         self.current_frame_number = frame_num
+        if self.flag_all_localization_df:
+            circled_mask = self.create_circle_apply_toAll_pd(input_mask=self.maskArray, position_df=self.df_PSFs, parallel_flag=False)
+
+            self.different_views[self.title].viewer.maskArray = circled_mask
+            self.different_views[self.title].viewer.mask_is_set = True
+            mask_pixmap = self.different_views[self.title].viewer.create_mask_pixmap(circled_mask[self.current_frame_number, :, :])
+            self.different_views[self.title].viewer.update_overlay(mask_pixmap)
+            self.different_views[self.title].get_in(self.df_PSFs)
+        elif self.flag_all_localization_ndarray:
+            pass
 
     def new_display(self, display_input, original_video, object=None, title=None, mask_status=False, position_list=None):
 
@@ -54,6 +66,7 @@ class Visulization_localization(QtWidgets.QMainWindow):
 
             if object is not None:
                 self.different_views[title].currentFrame.connect(object.get_sliceNumber)
+                self.different_views[title].currentFrame.connect(self.get_sliceNumber)
 
     def create_circle(self, x, y, r, shape):
         rr, cc = circle_perimeter(x, y, r, shape=shape)
@@ -72,7 +85,6 @@ class Visulization_localization(QtWidgets.QMainWindow):
             x_positions = position_df['x'].tolist()
             y_positions = position_df['y'].tolist()
             sigmas = position_df['sigma'].tolist()
-            # particle_labels = particle['particle'].tolist()
 
             if parallel_flag:
                 self.input_mask = input_mask
@@ -80,15 +92,19 @@ class Visulization_localization(QtWidgets.QMainWindow):
                     delayed(self.create_circle_apply_oneFrame_pd)(x_, y_, s_, f_) for x_, y_, s_, f_ in tqdm(zip(x_positions, y_positions, sigmas, frames)))
                 input_mask = self.input_mask
             else:
-
-                for x_, y_, s_, f_ in tqdm(zip(x_positions, y_positions, sigmas, frames)):
+                psf_current_frame = position_df.loc[position_df['frame'] == self.current_frame_number]
+                frames = psf_current_frame['frame'].tolist()
+                x_positions = psf_current_frame['x'].tolist()
+                y_positions = psf_current_frame['y'].tolist()
+                sigmas = psf_current_frame['sigma'].tolist()
+                for x_, y_, s_, f_ in zip(x_positions, y_positions, sigmas, frames):
                     y = int(x_)
                     x = int(y_)
                     radius = int(np.sqrt(2) * s_)
                     rr, cc = self.create_circle(x, y, radius, input_mask[0, :, :].shape)
                     self.maskArray[int(f_), rr.astype(int), cc.astype(int)] = True
+                input_mask = self.maskArray
 
-            print("-------------------MaskArray is now updated.-------------------")
         else:
             self.msg_box = QtWidgets.QMessageBox()
             self.msg_box.setWindowTitle("Warning!")
@@ -109,6 +125,7 @@ class Visulization_localization(QtWidgets.QMainWindow):
                         rr, cc = self.create_circle(y, x, radius, input_mask[0, :, :].shape)
                         input_mask[frame_number, rr, cc] = True
             else:
+
                 frame_number = int(position_list[0, 0])
                 for j_ in range(position_list.shape[0]):
                     y = int(position_list[j_, 1])
@@ -117,7 +134,6 @@ class Visulization_localization(QtWidgets.QMainWindow):
                     radius = int(np.sqrt(2) * sigma)
                     rr, cc = self.create_circle(y, x, radius, input_mask[0, :, :].shape)
                     input_mask[frame_number, rr, cc] = True
-            print("-------------------MaskArray is now updated.-------------------")
         else:
             self.msg_box = QtWidgets.QMessageBox()
             self.msg_box.setWindowTitle("Warning!")
@@ -148,11 +164,16 @@ class Visulization_localization(QtWidgets.QMainWindow):
 
     @QtCore.Slot()
     def update_localization_onMask(self, video_in, df_PSFs, title, flag_preview=False):
+        self.flag_all_localization_ndarray = False
+        self.flag_all_localization_df = False
+        self.df_PSFs = df_PSFs
+        self.title = title
         try:
             self.maskArray = np.zeros_like(video_in, dtype="bool")
 
             if type(df_PSFs) is np.ndarray:
                 circled_mask = self.create_circle_apply_toAll_list(self.maskArray, df_PSFs, flag_preview=True)
+                self.flag_all_localization_ndarray = True
                 print('list_done')
 
             elif type(df_PSFs) is pd.core.frame.DataFrame:
@@ -160,7 +181,8 @@ class Visulization_localization(QtWidgets.QMainWindow):
                     circled_mask = self.create_circle_apply_toAll_pd(self.maskArray, df_PSFs, parallel_flag=False)
 
                 else:
-                    circled_mask = self.create_circle_apply_toAll_pd(self.maskArray, df_PSFs, parallel_flag=True)
+                    circled_mask = self.create_circle_apply_toAll_pd(self.maskArray, df_PSFs, parallel_flag=False)
+                    self.flag_all_localization_df = True
 
             self.different_views[title].viewer.maskArray = circled_mask
             self.different_views[title].viewer.mask_is_set = True
